@@ -19,7 +19,7 @@ from urllib.parse import urljoin
 
 
 class TT_API:
-    def __init__(self, to_users: list):
+    def __init__(self, to_users=[]):
         self._appid = 'health-data'
         self._secret = '7c77496167924d4e9581d44c7dc8987a'
         self._host = 'https://ttapi.myoas.com'
